from setuptools import setup, find_packages
setup(
        name="crcmodbus",
        version="1.0",
        description="",
        author="jdh99",
        author_email="jdh821@163.com",
        url="https://gitee.com/jdhxyy/crc16-python",
        packages=find_packages(),
    )
